@@ -44,7 +44,11 @@ class BiomajConfig(object):
         'keep.old.sessions': 0,
         'docker.sudo': '1',
         'auto_publish': 0,
-        'use_hardlinks': 0
+        'use_hardlinks': 0,
+        'wait_policy': 'wait_fixed(3)',
+        'stop_condition': 'stop_after_attempt(3)',
+        'ssh_hosts_file': os.path.expanduser('~/.ssh/known_hosts'),
+        'ssh_new_host': 'reject',
     }
 
     # Old biomaj level compatibility
@@ -361,12 +365,12 @@ class BiomajConfig(object):
             logging.warn('db.fullname is not set')
         if not self.get('db.formats'):
             logging.warn('db.formats is not set')
-        if self.get('use_ldap'):
+        if self.get_bool('use_ldap'):
             if not self.get('ldap.host') or not self.get('ldap.port') or \
                     not self.get('ldap.dn'):
                 logging.error('use_ldap set to 1 but missing configuration')
                 status = False
-        if self.get('use_elastic'):
+        if self.get_bool('use_elastic'):
             if not self.get('elastic_nodes') or not self.get('elastic_index'):
                 logging.error('use_elastic set to 1 but missing configuration')
                 status = False
