@@ -126,13 +126,17 @@ class Utils(object):
         :param folder: directory path
         :type folder: str
         """
+        logger = logging.getLogger('biomaj')
         if not os.path.exists(folder):
             return -1
         folder_size = 0
         for (path, dirs, files) in os.walk(folder):
             for ffile in files:
                 filename = os.path.join(path, ffile)
-                folder_size += os.path.getsize(filename)
+                try:
+                    folder_size += os.path.getsize(filename)
+                except Exception:
+                    logger.error('[stat][size] file not found %s' % filename)
         return folder_size
 
     @staticmethod
@@ -157,7 +161,7 @@ class Utils(object):
             return None
         # release = None
         rfile = files[0]
-        release = {'year': rfile['year'], 'month': rfile['month'], 'day': rfile['day']}
+        release = {'year': rfile['year'], 'month': rfile['month'], 'day': rfile['day'], 'file': rfile}
         for rfile in files:
             rel_date = datetime.date(int(release['year']), int(release['month']), int(release['day']))
             file_date = datetime.date(int(rfile['year']), int(rfile['month']), int(rfile['day']))
@@ -165,6 +169,7 @@ class Utils(object):
                 release['year'] = rfile['year']
                 release['month'] = rfile['month']
                 release['day'] = rfile['day']
+                release['file'] = rfile
         return release
 
     @staticmethod
